import UIKit
import Flutter
import AppTrackingTransparency

import adbrixrm_flutter

@UIApplicationMain
@objc class AppDelegate: FlutterAppDelegate {
    
    override func application(
        _ application: UIApplication,
        didFinishLaunchingWithOptions launchOptions: [UIApplication.LaunchOptionsKey: Any]?
    ) -> Bool {
        GeneratedPluginRegistrant.register(with: self)
        AdbrixrmFlutterPlugin.sdkInit(appKey: "YOUR_APPKEY", secretKey: "YOUR_SECRETKEY")
        
        
        return super.application(application, didFinishLaunchingWithOptions: launchOptions)
    }
    
    override func applicationDidBecomeActive(_ application: UIApplication) {
        if #available(iOS 14, *) {
            ATTrackingManager.requestTrackingAuthorization { (status) in
                switch status{
                case.authorized:
                    AdbrixrmFlutterPlugin.startGettingIDFA()
                case.denied:
                    AdbrixrmFlutterPlugin.stopGettingIDFA()
                case.notDetermined :
                    AdbrixrmFlutterPlugin.stopGettingIDFA()
                case.restricted:
                    AdbrixrmFlutterPlugin.stopGettingIDFA()
                default:
                    AdbrixrmFlutterPlugin.stopGettingIDFA()
                }
            }
        }
        
        
        let unCenter = UNUserNotificationCenter.current()
        unCenter.delegate = self
        let options : UNAuthorizationOptions = [.alert, .sound, .badge]
        
        unCenter.requestAuthorization(options: options, completionHandler: {(granted,error) in
            if granted{
                DispatchQueue.main.async {
                    // If Push permission is granted enable AdBrix Push
                    AdbrixrmFlutterPlugin.setPushEnable(toPushEnable: true)
                    application.registerForRemoteNotifications()
                    UIApplication.shared.registerForRemoteNotifications()
                }
            }
            else{
                // If Push permission is not granted disable AdBrix Push
                AdbrixrmFlutterPlugin.setPushEnable(toPushEnable: false)
            }
        })
        AdbrixrmFlutterPlugin.setInAppMessageClickListener()
    }
    
    
    override func application(_ app: UIApplication, open url: URL, options: [UIApplication.OpenURLOptionsKey : Any] = [:]) -> Bool {
        
        AdbrixrmFlutterPlugin.deeplinkOpen(with: url)
        return true
    }
    
    override func application(_ application: UIApplication, didRegisterForRemoteNotificationsWithDeviceToken deviceToken: Data) {
        
        AdbrixrmFlutterPlugin.setRegistrationId(deviceToken: deviceToken)
    }
    
    override func userNotificationCenter(_ center: UNUserNotificationCenter, didReceive response: UNNotificationResponse, withCompletionHandler completionHandler: @escaping () -> Void) {
        
//        if local
//        AdbrixrmFlutterPlugin.localPushOpen(center: center, response: response)
//        if remote
        AdbrixrmFlutterPlugin.remotePushOpen(center: center, response: response)
        completionHandler()
    }

}
