import 'dart:async';

import 'package:adbrixrm_flutter/adbrixrm.dart';
import 'package:adbrixrm_flutter_example/commerceEvent.dart';
import 'package:adbrixrm_flutter_example/gameEvent.dart';
import 'package:adbrixrm_flutter_example/userInfoEvent.dart';
import 'package:adbrixrm_flutter_example/v2ApiView.dart';

import 'package:flutter/material.dart';

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> with WidgetsBindingObserver {
  int _currentIndex = 0;
  List _page = [userInfoView(), commerceView(), gameView(), v2ApiView()];

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: _page[_currentIndex],
        ),
        bottomNavigationBar: BottomNavigationBar(
          fixedColor: Colors.blue,
          currentIndex: _currentIndex,
          onTap: onTabTapped,
          items: const <BottomNavigationBarItem>[
            BottomNavigationBarItem(icon: Icon(Icons.home), label: 'userinfo'),
            BottomNavigationBarItem(
                icon: Icon(Icons.credit_card), label: 'Commerce'),
            BottomNavigationBarItem(icon: Icon(Icons.gamepad), label: 'Game'),
            BottomNavigationBarItem(
                icon: Icon(Icons.accessibility_rounded), label: 'V2API')
          ],
        ),
      ),
    );
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState currentState) {
    if (currentState == AppLifecycleState.resumed) {
      debugPrint("App is onResume");
    }
  }

  @override
  void initState() {
    super.initState();

    AdBrixRm.setDeeplinkListener((deeplinkString) {
      debugPrint("****LISTENER! DEEPLINK = $deeplinkString");
    });
    AdBrixRm.setDeferredDeeplinkListener((deferredDeeplinkString) {
      debugPrint("****LISTENER! DEFERRED_DEEPLINK = $deferredDeeplinkString");
    });
    // AdBrixRm.setPushLocalCallbackListener((event) {
    //   debugPrint("****LISTENER! PUSH_LOCAL = $event");
    // });
    // AdBrixRm.setPushRemoteCallbackListener((event) {
    //   debugPrint("****LISTENER! PUSH_REMOTE = $event");
    // });
    AdBrixRm.setOnReceiveInAppMessageClickListener((event) {
      debugPrint("****LISTENER! IAM_CLICK = $event");
    });
    // AdBrixRm.setDidFetchInAppMessageListener((event) {
    //   debugPrint("****LISTENER! DID_FETCH = $event");
    // });
    // AdBrixRm.setDidPrintLogListener((event) {
    //   debugPrint("****Listener at main" + event);
    // });

    WidgetsBinding.instance.addObserver(this);

    debugPrint('abxrm :: appStart!! ');

    AdBrixRm.setPushEnable(isPushEnable: true);
    // AdBrixRm.setNotificationChannel("channelName", "channelDescription",
    //     NotificationManager.IMPORTANCE_HIGH, true);
    // AdBrixRm.setNotificationOption(
    //     NotificationCompat.PRIORITY_HIGH, NotificationCompat.VISIBILITY_PUBLIC);
  }

  void onTabTapped(int index) {
    switch (index) {
      case 0:
        AdBrixRm.event(eventName: 'userInfo');
        break;

      case 1:
        Map<String, dynamic> attr = <String, dynamic>{
          'value': 2,
          'string': 'this is commerce',
          'string2': 'this is String2',
          'double': 25000.00,
          'long': 2222222222222,
          'bool': false
        };
        AdBrixRm.event(eventName: 'commerce', attr: attr);
        break;

      case 2:
        Map<String, dynamic> attr = <String, dynamic>{
          'string': 'this is game',
          'int': 3,
          'bool': true,
          'long': 33333333333333,
          'double': 35000.00
        };

        AdBrixRm.event(eventName: 'game', attr: attr);

        break;
    }
    setState(() {
      _currentIndex = index;
    });
  }
}
